@@ -4,6 +4,7 @@ source("objects_for_tests.R")
 
 test_that("creating env", {
   skip_if_no_conda()
+  reticulate::use_condaenv("myenv")
   if ("myenv" %in% reticulate::conda_list()$name) {
     reticulate::conda_remove("myenv")
     name <-
@@ -23,6 +24,7 @@ test_that("creating env", {
 })
 test_that("if check", {
   skip_if_no_conda()
+  reticulate::use_condaenv("myenv")
   if (.Platform$OS.type == "unix") {
     expect_success(expect_message(create_env(yml = system.file("extdata", "testing_environment.yml", package = "DALEXtra")),
                                   "not specified"))
@@ -39,9 +41,6 @@ test_that("errors checks", {
   if ("myenv" %in% reticulate::conda_list()$name) {
     reticulate::conda_remove("myenv")
   }
-    expect_error(create_env(
-      system.file("extdata", "scikitlearn.yml", package = "DALEXtra")
-    ))
     expect_error(create_env(
       system.file("extdata", "scikitlearn.yml", package = "DALEXtra"),
       condaenv = "wrong_path"
